
{- |
Copyright  : Will Thompson, Iñaki García Etxebarria and Jonas Platte
License    : LGPL-2.1
Maintainer : Iñaki García Etxebarria (garetxe@gmail.com)
-}

module GI.Atk.Objects.GObjectAccessible
    ( 

-- * Exported types
    GObjectAccessible(..)                   ,
    GObjectAccessibleK                      ,
    toGObjectAccessible                     ,
    noGObjectAccessible                     ,


 -- * Methods
-- ** gObjectAccessibleForObject
    gObjectAccessibleForObject              ,


-- ** gObjectAccessibleGetObject
    gObjectAccessibleGetObject              ,




    ) where

import Prelude ()
import Data.GI.Base.ShortPrelude

import qualified Data.Text as T
import qualified Data.ByteString.Char8 as B
import qualified Data.Map as Map

import GI.Atk.Types
import GI.Atk.Callbacks
import qualified GI.GObject as GObject

newtype GObjectAccessible = GObjectAccessible (ForeignPtr GObjectAccessible)
foreign import ccall "atk_gobject_accessible_get_type"
    c_atk_gobject_accessible_get_type :: IO GType

type instance ParentTypes GObjectAccessible = GObjectAccessibleParentTypes
type GObjectAccessibleParentTypes = '[Object, GObject.Object]

instance GObject GObjectAccessible where
    gobjectIsInitiallyUnowned _ = False
    gobjectType _ = c_atk_gobject_accessible_get_type
    

class GObject o => GObjectAccessibleK o
instance (GObject o, IsDescendantOf GObjectAccessible o) => GObjectAccessibleK o

toGObjectAccessible :: GObjectAccessibleK o => o -> IO GObjectAccessible
toGObjectAccessible = unsafeCastTo GObjectAccessible

noGObjectAccessible :: Maybe GObjectAccessible
noGObjectAccessible = Nothing

type instance AttributeList GObjectAccessible = GObjectAccessibleAttributeList
type GObjectAccessibleAttributeList = ('[ '("accessible-component-layer", ObjectAccessibleComponentLayerPropertyInfo), '("accessible-component-mdi-zorder", ObjectAccessibleComponentMdiZorderPropertyInfo), '("accessible-description", ObjectAccessibleDescriptionPropertyInfo), '("accessible-hypertext-nlinks", ObjectAccessibleHypertextNlinksPropertyInfo), '("accessible-name", ObjectAccessibleNamePropertyInfo), '("accessible-parent", ObjectAccessibleParentPropertyInfo), '("accessible-role", ObjectAccessibleRolePropertyInfo), '("accessible-table-caption", ObjectAccessibleTableCaptionPropertyInfo), '("accessible-table-caption-object", ObjectAccessibleTableCaptionObjectPropertyInfo), '("accessible-table-column-description", ObjectAccessibleTableColumnDescriptionPropertyInfo), '("accessible-table-column-header", ObjectAccessibleTableColumnHeaderPropertyInfo), '("accessible-table-row-description", ObjectAccessibleTableRowDescriptionPropertyInfo), '("accessible-table-row-header", ObjectAccessibleTableRowHeaderPropertyInfo), '("accessible-table-summary", ObjectAccessibleTableSummaryPropertyInfo), '("accessible-value", ObjectAccessibleValuePropertyInfo)] :: [(Symbol, *)])

type instance SignalList GObjectAccessible = GObjectAccessibleSignalList
type GObjectAccessibleSignalList = ('[ '("active-descendant-changed", ObjectActiveDescendantChangedSignalInfo), '("children-changed", ObjectChildrenChangedSignalInfo), '("focus-event", ObjectFocusEventSignalInfo), '("notify", GObject.ObjectNotifySignalInfo), '("property-change", ObjectPropertyChangeSignalInfo), '("state-change", ObjectStateChangeSignalInfo), '("visible-data-changed", ObjectVisibleDataChangedSignalInfo), '("notify::[property]", GObjectNotifySignalInfo)] :: [(Symbol, *)])

-- method GObjectAccessible::get_object
-- method type : OrdinaryMethod
-- Args : [Arg {argName = "_obj", argType = TInterface "Atk" "GObjectAccessible", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "_obj", argType = TInterface "Atk" "GObjectAccessible", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TInterface "GObject" "Object"
-- throws : False
-- Skip return : False

foreign import ccall "atk_gobject_accessible_get_object" atk_gobject_accessible_get_object :: 
    Ptr GObjectAccessible ->                -- _obj : TInterface "Atk" "GObjectAccessible"
    IO (Ptr GObject.Object)


gObjectAccessibleGetObject ::
    (MonadIO m, GObjectAccessibleK a) =>
    a ->                                    -- _obj
    m GObject.Object
gObjectAccessibleGetObject _obj = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    result <- atk_gobject_accessible_get_object _obj'
    checkUnexpectedReturnNULL "atk_gobject_accessible_get_object" result
    result' <- (newObject GObject.Object) result
    touchManagedPtr _obj
    return result'

-- method GObjectAccessible::for_object
-- method type : MemberFunction
-- Args : [Arg {argName = "obj", argType = TInterface "GObject" "Object", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "obj", argType = TInterface "GObject" "Object", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TInterface "Atk" "Object"
-- throws : False
-- Skip return : False

foreign import ccall "atk_gobject_accessible_for_object" atk_gobject_accessible_for_object :: 
    Ptr GObject.Object ->                   -- obj : TInterface "GObject" "Object"
    IO (Ptr Object)


gObjectAccessibleForObject ::
    (MonadIO m, GObject.ObjectK a) =>
    a ->                                    -- obj
    m Object
gObjectAccessibleForObject obj = liftIO $ do
    let obj' = unsafeManagedPtrCastPtr obj
    result <- atk_gobject_accessible_for_object obj'
    checkUnexpectedReturnNULL "atk_gobject_accessible_for_object" result
    result' <- (newObject Object) result
    touchManagedPtr obj
    return result'


